<?php
/**
 * @file
 * ReoadTina admin file.
 */

/**
 * Settings form.
 */
function reloadtina_settings_form() {
  $form = [];

  $form['reloadtina_multipliers'] = [
    '#type' => 'textfield',
    '#title' => t('Multipliers'),
    '#description' => t('Enter which multipliers to support, separated by space. E.g. <em>1.5 2</em>'),
    '#default_value' => implode(' ', reloadtina_get_multipliers()),
  ];
  $form['reloadtina_default'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable reloadtina by default for image styles.'),
    '#default_value' => variable_get('reloadtina_default', TRUE),
  ];

  $image_styles = image_styles();
  $headers = [t('Image style'), t('Status')];

  $statuses = [
    RELOADTINA_DEFAULT => t('Default'),
    RELOADTINA_DISABLED => t('Disabled'),
    RELOADTINA_ENABLED => t('Enabled'),
  ];

  $rows = [];

  foreach ($image_styles as $style_name => $image_style) {
    $row = [];
    $row['label'] = ['#markup' => $image_style['label']];
    $row['status'] = [
      '#type' => 'select',
      '#options' => $statuses,
      '#default_value' => variable_get("reloadtina_default_$style_name", RELOADTINA_DEFAULT),
    ];
    $rows[$style_name] = $row;
  }
  $rows['#tree'] = TRUE;
  $form['image_styles_table'] = [
    '#theme' => 'reloadtina_table_form',
    '#header' => $headers,
    'image_styles' => $rows,
  ];

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = ['#type' => 'submit', '#value' => t('Save configuration')];

  if (!empty($_POST) && form_get_errors()) {
    drupal_set_message(t('The settings have not been saved because of the errors.'), 'error');
  }
  $form['#submit'][] = 'reloadtina_settings_form_submit';
  // By default, render the form using theme_system_settings_form().
  if (!isset($form['#theme'])) {
    $form['#theme'] = 'system_settings_form';
  }

  return $form;
}

/**
 * Validate handler.
 */
function reloadtina_settings_form_validate($form, &$form_state) {
  $multipliers = explode(' ', $form_state['values']['reloadtina_multipliers']);
  foreach ($multipliers as $multiplier) {
    $multiplier = trim($multiplier);
    if (!is_numeric($multiplier)) {
      form_set_error('reloadtina_multipliers', t('Invalid multiplier: %multiplier', ['%multiplier' => $multiplier]));
    }
  }
}

/**
 * Submit handler.
 */
function reloadtina_settings_form_submit($form, &$form_state) {
  $multipliers = explode(' ', $form_state['values']['reloadtina_multipliers']);
  foreach ($multipliers as &$multiplier) {
    $multiplier = trim($multiplier);
  }
  variable_set('reloadtina_multipliers', $multipliers);
  variable_set('reloadtina_default', $form_state['values']['reloadtina_default']);
  foreach ($form_state['values']['image_styles'] as $style_name => $image_style) {
    variable_set("reloadtina_default_$style_name", $image_style['status']);
  }
}
